/*-------------------------------------------------------------------------------
*
* glcd_demo.ino
*
* Plots curves, boxes, circles and text to the glcd screen
* to demonstrate the functionality of the module
*
* Stephan Laage-Witt - 07-Mar-2018
*-------------------------------------------------------------------------------*/

#include <Wire.h>
#include <math.h>
#include <glcd_functions.h>

// global variables
glcd gd(0x20);
uint8_t max_x, max_y;
int8_t sin_data[200];

void setup() {
  char str_buf[30];
  
  Wire.begin();

  // initiate display
  gd.get_max_xy(&max_x, &max_y);
  gd.clear_screen();
  gd.set_light(10);

  // draw x_scale with labels
  uint8_t x_pos;
  gd.draw_line(10, 31, max_x - 10, 31, 1);
  gd.set_font(1);
  for (uint8_t i = 2; i <= 9; ++i) {
    x_pos = 10 + i * 20;
    if (x_pos >= max_x - 10) break;
    gd.draw_line(x_pos, 31, x_pos, 34, 1);
    gd.set_cursor(x_pos - 4, 36);
    gd.draw_udec((i - 1) * 10, 2, 1);  
  };

  // draw y_scale (no labels)
  gd.draw_line(30, 0, 30, max_y, 1);

  // draw sinus curve
  for (uint8_t i = 0; i < max_x; ++i) 
    sin_data[i] = (int) 20 * sin(i / 10.0) + 31;
   gd.draw_function(max_x, 0, 1, sin_data);
  for (uint8_t i = 0; i < max_x; ++i) 
    sin_data[i] = (int) 32 * sin(i / 10.0) + 31;
   gd.draw_function(max_x, 0, 1, sin_data);
   delay(50);   // wait until the operations above are completed and the I2C buffer is empty
                // alternatively, check the status of "buffer_empty" signal  

  // draw main title
  uint8_t x_center = max_x / 2, y_start = 7;
  uint8_t title_height, title_width, half_width;
  strcpy(str_buf, "Smart I2C Graphic");
  gd.set_font(6);
  title_height = gd.get_font_height();
  title_width = gd.get_str_width(str_buf);
  half_width = title_width / 2;
  gd.draw_filled_rectangle(x_center - half_width - 2, y_start - 2, 
    x_center + half_width + 2, y_start + title_height + 1, 0);
  gd.draw_rectangle(x_center - half_width - 3, y_start - 3,
    x_center + half_width + 3, y_start + title_height + 2, 1);
  gd.draw_rectangle(x_center - half_width - 4, y_start - 4,
    x_center + half_width + 4, y_start + title_height + 3, 1);
  gd.set_cursor(x_center - half_width, y_start);
  gd.draw_str(str_buf);

  // draw circle markers
  uint8_t x_mark, y_mark;
  // 1st marker, right side
  x_mark = max_x - 9;
  y_mark = max_y - 9;
  gd.draw_filled_circle(x_mark, y_mark, 7, 0b00000101, 1);
  gd.draw_circle(x_mark, y_mark, 9, 0xff, 1);
  // 2nd marker, left side
  x_mark = 9;
  y_mark = max_y - 9;
  gd.draw_filled_circle(x_mark, y_mark, 7, 0b00000101, 1);
  gd.draw_circle(x_mark, y_mark, 9, 0xff, 1);

  // draw bottom string
  strcpy(str_buf, "Graphics for small systems");
  gd.set_font(4);
  gd.set_cursor(x_center, 47);
  gd.draw_center_str(str_buf);   
}

void loop() {
  // put your main code here, to run repeatedly:

}
